FxRibbonIconSource class

Runtime icon source for ribbon rendering.

Annotations

Constructors

FxRibbonIconSource.fromEmbedded(FxRibbonEmbeddedIcon icon)
Creates a runtime icon source from an embedded bundle asset.
factory
FxRibbonIconSource.imageProvider(ImageProvider<Object> imageProvider)
Creates an image provider source.
const
FxRibbonIconSource.material(IconData icon)
Creates a Material icon source.
const
FxRibbonIconSource.pngAsset(String assetName, {String? package})
Creates a PNG asset source.
const
FxRibbonIconSource.pngBytes(Uint8List pngBytes)
Creates embedded PNG bytes.
const
FxRibbonIconSource.svgAsset(String assetName, {String? package})
Creates an SVG asset source.
const
FxRibbonIconSource.svgString(String svgString)
Creates an embedded SVG source.
const

Properties

assetName String?
Asset name for asset-backed sources.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Material icon data.
final
imageProvider ImageProvider<Object>?
Image provider.
final
kind FxRibbonIconKind
Source kind.
final
package String?
Optional package name for asset-backed sources.
final
pngBytes Uint8List?
PNG bytes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
svgString String?
SVG markup.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited