FxTextInputFormat class

Serializable single-line text display format.

Constructors

FxTextInputFormat.none()
Creates a no-op format.
const
FxTextInputFormat.number({int? decimalDigits = 2, String groupingSeparator = ',', String decimalSeparator = '.', bool allowNegative = false})
Creates a commit-time fixed decimal number format.
const
FxTextInputFormat.pattern(String? pattern)
Creates a digit pattern format. # placeholders consume digits.
const

Properties

allowNegative bool
Whether a leading minus sign is accepted for number formatting.
final
decimalDigits int?
Fixed decimal digits for FxTextInputFormatType.number.
final
decimalSeparator String
Decimal separator for FxTextInputFormatType.number.
final
groupingSeparator String
Group separator for FxTextInputFormatType.number.
final
hashCode int
The hash code for this object.
no setterinherited
pattern String?
Pattern string for FxTextInputFormatType.pattern.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type FxTextInputFormatType
Format kind.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toTemplateMap() Map<String, Object?>
Stable map for AI/generator use.

Operators

operator ==(Object other) bool
The equality operator.
inherited