FxCellType class sealed
Defines rendering and interaction strategies for list/grid cells.
- Implementers
Constructors
- FxCellType.boolean()
-
Creates a boolean cell type (renders a checkbox directly in the cell).
constfactory
-
FxCellType.choice(List<
String> options) -
Creates a choice cell type (renders a dropdown menu when editing).
constfactory
-
FxCellType.fromJson(Map<
String, Object?> json) -
Parses an FxCellType from a JSON map.
factory
- FxCellType.lookup(FxLookupProvider provider)
-
Creates a lookup cell type.
constfactory
- FxCellType.text()
-
Creates a text cell type (renders a standard text widget).
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this cell type to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited