FxDbLookupProvider<K> class
A database-style multi-column lookup provider.
- Inheritance
-
- Object
- FxLookupProvider<
K> - FxDbLookupProvider
Constructors
Properties
- displayColumnIndex → int
-
Index of the column within the list of values that contains the main display value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
String> -
The headers of the lookup columns.
final
-
recordMap
→ Map<
K, List< String> > -
The map of keys to a list of strings representing the row values.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDisplayValue(
K key) → String -
Maps a raw database Key/ID back to a human-readable display string.
override
-
getLookupHeaders(
) → List< String> -
Returns the headers for a multi-column dropdown, if supported.
override
-
getOptions(
String query) → FutureOr< List< FxLookupItem< >K> > -
Fetches options for selection, supporting search query filtering.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Converts this lookup provider configuration to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited