FxGridPlacementSpec class
Serializable placement metadata for grid layouts.
Constructors
Properties
- area → String?
-
Named grid area.
final
- columnSpan → int
-
Number of columns to span.
final
- columnStart → int?
-
Zero-based column start.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable child id.
final
- rowSpan → int
-
Number of rows to span.
final
- rowStart → int?
-
Zero-based row start.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this spec to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited