FxLocalizationKey class
Stable localization key metadata for tools and diagnostics.
Constructors
- FxLocalizationKey(String name, {String? context})
-
Creates a localization key with an optional translator context.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTemplateMap(
) → Map< String, Object?> - Stable map for diagnostics, docs, and generators.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited