FxUndoAction class
A reversible semantic operation tracked by FxUndoController.
Constructors
- FxUndoAction({required String label, required VoidCallback apply, required VoidCallback revert})
-
Creates an undoable action.
const
-
FxUndoAction.batch({required String label, required Iterable<
FxUndoAction> actions}) -
Creates one action from multiple operations.
factory
Properties
- apply → VoidCallback
-
Applies or reapplies the operation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Human-readable action name shown in menus and toolbars.
final
- revert → VoidCallback
-
Reverts the operation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited